@@ -3,6 +3,7 @@
 set -o errexit
 
 FORCE_GENERATE="${FORCE_GENERATE}"
+HASH_PATH=/var/lib/kolla/.settings.md5sum.txt
 
 if [[ ${KOLLA_INSTALL_TYPE} == "binary" ]]; then
     SITE_PACKAGES="/usr/lib/python2.7/site-packages"
@@ -288,11 +289,9 @@ function settings_bundle {
 
 function settings_changed {
     changed=1
-    hash_path=/var/lib/kolla/.settings.md5sum.txt
 
-    if [[ ! -f $hash_path  ]] || ! settings_bundle | md5sum -c --status $hash_path || [[ $FORCE_GENERATE == yes ]]; then
+    if [[ ! -f $HASH_PATH  ]] || ! settings_bundle | md5sum -c --status $HASH_PATH || [[ $FORCE_GENERATE == yes ]]; then
         changed=0
-        settings_bundle | md5sum > $hash_path
     fi
 
     return ${changed}
@@ -343,6 +342,7 @@ if settings_changed; then
         /var/lib/kolla/venv/bin/python /var/lib/kolla/venv/bin/manage.py collectstatic --noinput --clear
         /var/lib/kolla/venv/bin/python /var/lib/kolla/venv/bin/manage.py compress --force
     fi
+    settings_bundle | md5sum > $HASH_PATH
 fi
 
 # NOTE(sbezverk) since Horizon is now storing logs in its own location, /var/log/horizon
